/*
 * @file main.c
 * @brief Est projeto implementa o exemplo 1 da secao 8.4.1/pg. 84 de KLQRUB 
 * @date 22/01/2023
 * @author Wu Shin-Ting
 */

#include "derivative.h"
#include "ISR.h"
#include "UART.h"
#include "SIM.h"
#include "MCG.h"

int main(void)
{
	/*
	 * Habilitar MCGFLLCLK 48MHz
	 */
	MCG_initFLL48MH();
	
	SIM_setaFLLPLL (0);              //seta FLL
	
	/*
	 * Configurar sinais de relogio e pinos
	 */
	UART0_config_basica(0b1);
	
	/*
	 * Configura o modulo UART0
	 */
	//MCGFLLCLK em 48MHz
	UART0_config_especifica (48000000, 115200, 0x0F);
	
#if UART_MODE == INTERRUPT_MODE
	//Diferente da sequencia sugerida no manual, habilitou a interrupcao do canal Rx 
	//apos a habilitacao dos canais Rx e Tx. A alteracao da ordem nao afeta 
	//no fluxo de controle, mas permite uma melhor organizacao dos codigos.
	UART0_habilitaInterruptRxTerminal();
	
	//enable_irq(12); set_irq_priority(12, 3);
	UART0_habilitaNVICIRQ12(0b11);
#endif	

	for(;;) {	
#if UART_MODE == POLLING_MODE
		uint8_t c;
		
		while(!(UART0_S1&UART_S1_RDRF_MASK));
		c = UART0_D;
		while(!(UART0_S1&UART_S1_TDRE_MASK) && !(UART0_S1&UART_S1_TC_MASK));
		UART0_D = c;
#endif
	}
	
	return 0;
}
